# Table of Contents

- [technical-users](<./technical-users.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Technical Users](<./Technical-Users.md>)
  - [Creating a Technical User](<./Technical-Users/Creating-a-Technical-User.md>)
  - [Managing Technical Users](<./Technical-Users/Managing-Technical-Users.md>)
  - [Best Practices](<./Technical-Users/Best-Practices.md>)
